@@ -4,6 +4,7 @@ import enum
 import hashlib
 import io
 import json
+import os
 import random
 import re
 import uuid
@@ -33,6 +34,19 @@ class Utils:
     default_max_allowed_miles = 200 * 365
     pwd_context = CryptContext(schemes=["sha256_crypt"])
 
+    # Datetime
+    @staticmethod
+    def datetime_from_epoch(epoch_timestamp: Union[int, float], tz: timezone =timezone.utc) -> datetime:
+        """
+        Converts an epoch timestamp (in seconds or milliseconds) to a datetime in a give timezone, defaults to UTC.
+        Automatically detects if input is in milliseconds and converts accordingly.
+        """
+        # If it's too large, treat it as milliseconds
+        if epoch_timestamp > 1e11:
+            epoch_timestamp /= 1000  # convert ms to seconds
+
+        return datetime.fromtimestamp(epoch_timestamp, tz=tz)
+
     # Datetime
     @staticmethod
     def datetime_now() -> datetime:
@@ -438,12 +452,26 @@ class FileUtils:
         return size
 
     @staticmethod
-    def create_upload_file(path: str, filename: str = None, content_type: str = None) -> UploadFile:
+    def create_upload_file_from_path(file_path: str, filename: str = None, content_type: str = None) -> UploadFile:
 
-        with open(path, "rb") as f:
+        with open(file_path, "rb") as f:
             content = f.read()
-        stream = io.BytesIO(content)
-        return UploadFile(filename=filename or path.split("/")[-1], file=stream, headers={"content_type": content_type})
+        file_stream = io.BytesIO(content)
+        return UploadFile(filename=filename or file_path.split("/")[-1], file=file_stream, headers={"content_type": content_type})
+
+    @staticmethod
+    def create_upload_file_from_bytes(file_bytes: bytes, filename: str, content_type: str = None) -> UploadFile:
+
+        file_stream = io.BytesIO(file_bytes)
+        return UploadFile(filename=filename, file=file_stream, headers={"content_type": content_type})
+
+    @staticmethod
+    def delete_file_if_exists(file_path: str):
+        if os.path.exists(file_path):
+            os.remove(file_path)
+            print(f"Deleted: {file_path}")
+        else:
+            print(f"File not found: {file_path}")
 
 
 class Base64Utils:
