@@ -101,7 +101,7 @@ class DbUtils:
     @staticmethod
     def _build_condition(column, op: str, value):
         match op:
-            case "=":
+            case "==":
                 return column == value
             case "!=":
                 return column != value
