@@ -52,7 +52,9 @@ class GenericRepo(Generic[ModelType, CreateSchemaType, UpdateSchemaType, QuerySc
         return result.scalar() is not None
 
     async def get(self, _id: Any, query_fields: str = None) -> Optional[SuccessResponse[QuerySchemaType]]:
-        return await self.get_model(_id, query_fields)
+        row = await self.get_model(_id, query_fields)
+
+        return self._db_utils.build_row_response(row)
 
     async def get_model(self, _id: Union[str, uuid.UUID], query_fields: Optional[str] = None) -> Optional[ModelType]:
         row, _ =  await self._get_model_by_id(_id, query_fields, include_deleted=False)
